# catslog
A python package which, as implied by it's name, does two things. Logs(function execution along with the arguments passed) and catch(es) a potential exception. It is a name combination of two things people love. (Chocolate)logs and cats.

The original goal, was to get rid of some boilerplate code as well as prettifying them, because I noticed "too many functions" follow the pattern:

- Enter function body
- Log stuff
- Catch potential exceptions
